@@ -8,10 +8,6 @@
  * GAIL - The GNOME Accessibility Implementation Library
  * Copyright 2001, 2002, 2003 Sun Microsystems Inc.
  *
- * Implementation of atk_text_get_text_[before/at/after]_offset
- * copied from gtkpango.c, part of GTK+ project
- * Copyright (c) 2010 Red Hat, Inc.
- *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -39,6 +35,35 @@
  *
  */
 
+/*
+ * IMPLEMENTATION NOTES:
+ *
+ * * AtkText: There are still some methods not implemented yet:
+ *     atk_text_get_default_attributes
+ *     atk_text_get_character_extents
+ *     atk_text_get_offset_at_point
+ *
+ *     See details on bug CB#1733
+ *
+ * * AtkEditableText: some methods will not be implemented
+ *
+ *     * atk_editable_text_set_run_attributes: ClutterText has some
+ *       properties equivalent to the AtkAttributte, but it doesn't
+ *       allow you to define it by
+ *
+ *     * atk_editable_text_copy: Clutter has no Clipboard support
+ *
+ *     * atk_editable_text_paste: Clutter has no Clipboard support
+ *
+ *     * atk_editable_text_cut: Clutter has no Clipboard support. In
+ *           this case, as cut is basically a copy&delete combination,
+ *           we could have implemented it using the delete, but IMHO,
+ *           it would be weird to cut a text, get the text removed and
+ *           then not be able to paste the text
+ *
+ *     See details on bug CB#1734
+ */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -48,11 +73,14 @@
 
 #include "clutter-main.h"
 
+static void cally_text_class_init (CallyTextClass *klass);
+static void cally_text_init       (CallyText *cally_text);
 static void cally_text_finalize   (GObject *obj);
 
 /* AtkObject */
 static void                   cally_text_real_initialize (AtkObject *obj,
                                                           gpointer   data);
+static const gchar *          cally_text_get_name        (AtkObject *obj);
 static AtkStateSet*           cally_text_ref_state_set   (AtkObject *obj);
 
 /* atkaction */
@@ -172,6 +200,17 @@ static int                  _cally_misc_get_index_at_point (ClutterText *clutter
                                                             gint         y,
                                                             AtkCoordType coords);
 
+G_DEFINE_TYPE_WITH_CODE (CallyText,
+                         cally_text,
+                         CALLY_TYPE_ACTOR,
+                         G_IMPLEMENT_INTERFACE (ATK_TYPE_TEXT,
+                                                cally_text_text_interface_init)
+                         G_IMPLEMENT_INTERFACE (ATK_TYPE_EDITABLE_TEXT,
+                                                cally_text_editable_text_interface_init));
+
+#define CALLY_TEXT_GET_PRIVATE(obj) \
+  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CALLY_TYPE_TEXT, CallyTextPrivate))
+
 struct _CallyTextPrivate
 {
   /* Cached ClutterText values*/
@@ -179,13 +218,13 @@ struct _CallyTextPrivate
   gint selection_bound;
 
   /* text_changed::insert stuff */
-  const gchar *signal_name_insert;
+  gchar *signal_name_insert;
   gint position_insert;
   gint length_insert;
   guint insert_idle_handler;
 
   /* text_changed::delete stuff */
-  const gchar *signal_name_delete;
+  gchar *signal_name_delete;
   gint position_delete;
   gint length_delete;
 
@@ -193,15 +232,6 @@ struct _CallyTextPrivate
   guint activate_action_id;
 };
 
-G_DEFINE_TYPE_WITH_CODE (CallyText,
-                         cally_text,
-                         CALLY_TYPE_ACTOR,
-                         G_ADD_PRIVATE (CallyText)
-                         G_IMPLEMENT_INTERFACE (ATK_TYPE_TEXT,
-                                                cally_text_text_interface_init)
-                         G_IMPLEMENT_INTERFACE (ATK_TYPE_EDITABLE_TEXT,
-                                                cally_text_editable_text_interface_init));
-
 static void
 cally_text_class_init (CallyTextClass *klass)
 {
@@ -212,15 +242,18 @@ cally_text_class_init (CallyTextClass *klass)
   gobject_class->finalize = cally_text_finalize;
 
   class->initialize = cally_text_real_initialize;
+  class->get_name   = cally_text_get_name;
   class->ref_state_set = cally_text_ref_state_set;
 
   cally_class->notify_clutter = cally_text_notify_clutter;
+
+  g_type_class_add_private (gobject_class, sizeof (CallyTextPrivate));
 }
 
 static void
 cally_text_init (CallyText *cally_text)
 {
-  CallyTextPrivate *priv = cally_text_get_instance_private (cally_text);
+  CallyTextPrivate *priv = CALLY_TEXT_GET_PRIVATE (cally_text);
 
   cally_text->priv = priv;
 
@@ -312,9 +345,32 @@ cally_text_real_initialize(AtkObject *obj,
   _check_activate_action (cally_text, clutter_text);
 
   if (clutter_text_get_password_char (clutter_text) != 0)
-    atk_object_set_role (obj, ATK_ROLE_PASSWORD_TEXT);
+    obj->role = ATK_ROLE_PASSWORD_TEXT;
   else
-    atk_object_set_role (obj, ATK_ROLE_TEXT);
+    obj->role = ATK_ROLE_TEXT;
+}
+
+static const gchar *
+cally_text_get_name (AtkObject *obj)
+{
+  const gchar *name;
+
+  g_return_val_if_fail (CALLY_IS_ACTOR (obj), NULL);
+
+  name = ATK_OBJECT_CLASS (cally_text_parent_class)->get_name (obj);
+  if (name == NULL)
+    {
+      ClutterActor *actor = NULL;
+
+      actor = CALLY_GET_CLUTTER_ACTOR (obj);
+
+      if (actor == NULL) /* State is defunct */
+        name = NULL;
+      else
+        name = clutter_text_get_text (CLUTTER_TEXT (actor));
+    }
+
+  return name;
 }
 
 static AtkStateSet*
@@ -339,706 +395,6 @@ cally_text_ref_state_set   (AtkObject *obj)
   return result;
 }
 
-/***** pango stuff ****
- *
- * FIXME: all this pango related code used to implement
- * atk_text_get_text_[before/at/after]_offset was copied from GTK, and
- * should be on a common library (like pango itself).
- *
- *********************/
-
-/*
- * _gtk_pango_move_chars:
- * @layout: a #PangoLayout
- * @offset: a character offset in @layout
- * @count: the number of characters to move from @offset
- *
- * Returns the position that is @count characters from the
- * given @offset. @count may be positive or negative.
- *
- * For the purpose of this function, characters are defined
- * by what Pango considers cursor positions.
- *
- * Returns: the new position
- */
-static gint
-_gtk_pango_move_chars (PangoLayout *layout,
-                       gint         offset,
-                       gint         count)
-{
-  const PangoLogAttr *attrs;
-  gint n_attrs;
-
-  attrs = pango_layout_get_log_attrs_readonly (layout, &n_attrs);
-
-  while (count > 0 && offset < n_attrs - 1)
-    {
-      do
-        offset++;
-      while (offset < n_attrs - 1 && !attrs[offset].is_cursor_position);
-
-      count--;
-    }
-  while (count < 0 && offset > 0)
-    {
-      do
-        offset--;
-      while (offset > 0 && !attrs[offset].is_cursor_position);
-
-      count++;
-    }
-
-  return offset;
-}
-
-/*
- * _gtk_pango_move_words:
- * @layout: a #PangoLayout
- * @offset: a character offset in @layout
- * @count: the number of words to move from @offset
- *
- * Returns the position that is @count words from the
- * given @offset. @count may be positive or negative.
- *
- * If @count is positive, the returned position will
- * be a word end, otherwise it will be a word start.
- * See the Pango documentation for details on how
- * word starts and ends are defined.
- *
- * Returns: the new position
- */
-static gint
-_gtk_pango_move_words (PangoLayout  *layout,
-                       gint          offset,
-                       gint          count)
-{
-  const PangoLogAttr *attrs;
-  gint n_attrs;
-
-  attrs = pango_layout_get_log_attrs_readonly (layout, &n_attrs);
-
-  while (count > 0 && offset < n_attrs - 1)
-    {
-      do
-        offset++;
-      while (offset < n_attrs - 1 && !attrs[offset].is_word_end);
-
-      count--;
-    }
-  while (count < 0 && offset > 0)
-    {
-      do
-        offset--;
-      while (offset > 0 && !attrs[offset].is_word_start);
-
-      count++;
-    }
-
-  return offset;
-}
-
-/*
- * _gtk_pango_move_sentences:
- * @layout: a #PangoLayout
- * @offset: a character offset in @layout
- * @count: the number of sentences to move from @offset
- *
- * Returns the position that is @count sentences from the
- * given @offset. @count may be positive or negative.
- *
- * If @count is positive, the returned position will
- * be a sentence end, otherwise it will be a sentence start.
- * See the Pango documentation for details on how
- * sentence starts and ends are defined.
- *
- * Returns: the new position
- */
-static gint
-_gtk_pango_move_sentences (PangoLayout  *layout,
-                           gint          offset,
-                           gint          count)
-{
-  const PangoLogAttr *attrs;
-  gint n_attrs;
-
-  attrs = pango_layout_get_log_attrs_readonly (layout, &n_attrs);
-
-  while (count > 0 && offset < n_attrs - 1)
-    {
-      do
-        offset++;
-      while (offset < n_attrs - 1 && !attrs[offset].is_sentence_end);
-
-      count--;
-    }
-  while (count < 0 && offset > 0)
-    {
-      do
-        offset--;
-      while (offset > 0 && !attrs[offset].is_sentence_start);
-
-      count++;
-    }
-
-  return offset;
-}
-
-/*
- * _gtk_pango_is_inside_word:
- * @layout: a #PangoLayout
- * @offset: a character offset in @layout
- *
- * Returns whether the given position is inside
- * a word.
- *
- * Returns: %TRUE if @offset is inside a word
- */
-static gboolean
-_gtk_pango_is_inside_word (PangoLayout  *layout,
-                           gint          offset)
-{
-  const PangoLogAttr *attrs;
-  gint n_attrs;
-
-  attrs = pango_layout_get_log_attrs_readonly (layout, &n_attrs);
-
-  while (offset >= 0 &&
-         !(attrs[offset].is_word_start || attrs[offset].is_word_end))
-    offset--;
-
-  if (offset >= 0)
-    return attrs[offset].is_word_start;
-
-  return FALSE;
-}
-
-/*
- * _gtk_pango_is_inside_sentence:
- * @layout: a #PangoLayout
- * @offset: a character offset in @layout
- *
- * Returns whether the given position is inside
- * a sentence.
- *
- * Returns: %TRUE if @offset is inside a sentence
- */
-static gboolean
-_gtk_pango_is_inside_sentence (PangoLayout  *layout,
-                               gint          offset)
-{
-  const PangoLogAttr *attrs;
-  gint n_attrs;
-
-  attrs = pango_layout_get_log_attrs_readonly (layout, &n_attrs);
-
-  while (offset >= 0 &&
-         !(attrs[offset].is_sentence_start || attrs[offset].is_sentence_end))
-    offset--;
-
-  if (offset >= 0)
-    return attrs[offset].is_sentence_start;
-
-  return FALSE;
-}
-
-static void
-pango_layout_get_line_before (PangoLayout     *layout,
-                              AtkTextBoundary  boundary_type,
-                              gint             offset,
-                              gint            *start_offset,
-                              gint            *end_offset)
-{
-  PangoLayoutIter *iter;
-  PangoLayoutLine *line, *prev_line = NULL, *prev_prev_line = NULL;
-  gint index, start_index, end_index;
-  const gchar *text;
-  gboolean found = FALSE;
-
-  text = pango_layout_get_text (layout);
-  index = g_utf8_offset_to_pointer (text, offset) - text;
-  iter = pango_layout_get_iter (layout);
-  do
-    {
-      line = pango_layout_iter_get_line (iter);
-      start_index = line->start_index;
-      end_index = start_index + line->length;
-
-      if (index >= start_index && index <= end_index)
-        {
-          /* Found line for offset */
-          if (prev_line)
-            {
-              switch (boundary_type)
-                {
-                case ATK_TEXT_BOUNDARY_LINE_START:
-                  end_index = start_index;
-                  start_index = prev_line->start_index;
-                  break;
-                case ATK_TEXT_BOUNDARY_LINE_END:
-                  if (prev_prev_line)
-                    start_index = prev_prev_line->start_index + prev_prev_line->length;
-                  else
-                    start_index = 0;
-                  end_index = prev_line->start_index + prev_line->length;
-                  break;
-                default:
-                  g_assert_not_reached();
-                }
-            }
-          else
-            start_index = end_index = 0;
-
-          found = TRUE;
-          break;
-        }
-
-      prev_prev_line = prev_line;
-      prev_line = line;
-    }
-  while (pango_layout_iter_next_line (iter));
-
-  if (!found)
-    {
-      start_index = prev_line->start_index + prev_line->length;
-      end_index = start_index;
-    }
-  pango_layout_iter_free (iter);
-
-  *start_offset = g_utf8_pointer_to_offset (text, text + start_index);
-  *end_offset = g_utf8_pointer_to_offset (text, text + end_index);
-}
-
-static void
-pango_layout_get_line_at (PangoLayout     *layout,
-                          AtkTextBoundary  boundary_type,
-                          gint             offset,
-                          gint            *start_offset,
-                          gint            *end_offset)
-{
-  PangoLayoutIter *iter;
-  PangoLayoutLine *line, *prev_line = NULL;
-  gint index, start_index, end_index;
-  const gchar *text;
-  gboolean found = FALSE;
-
-  text = pango_layout_get_text (layout);
-  index = g_utf8_offset_to_pointer (text, offset) - text;
-  iter = pango_layout_get_iter (layout);
-  do
-    {
-      line = pango_layout_iter_get_line (iter);
-      start_index = line->start_index;
-      end_index = start_index + line->length;
-
-      if (index >= start_index && index <= end_index)
-        {
-          /* Found line for offset */
-          switch (boundary_type)
-            {
-            case ATK_TEXT_BOUNDARY_LINE_START:
-              if (pango_layout_iter_next_line (iter))
-                end_index = pango_layout_iter_get_line (iter)->start_index;
-              break;
-            case ATK_TEXT_BOUNDARY_LINE_END:
-              if (prev_line)
-                start_index = prev_line->start_index + prev_line->length;
-              break;
-            default:
-              g_assert_not_reached();
-            }
-
-          found = TRUE;
-          break;
-        }
-
-      prev_line = line;
-    }
-  while (pango_layout_iter_next_line (iter));
-
-  if (!found)
-    {
-      start_index = prev_line->start_index + prev_line->length;
-      end_index = start_index;
-    }
-  pango_layout_iter_free (iter);
-
-  *start_offset = g_utf8_pointer_to_offset (text, text + start_index);
-  *end_offset = g_utf8_pointer_to_offset (text, text + end_index);
-}
-
-static void
-pango_layout_get_line_after (PangoLayout     *layout,
-                             AtkTextBoundary  boundary_type,
-                             gint             offset,
-                             gint            *start_offset,
-                             gint            *end_offset)
-{
-  PangoLayoutIter *iter;
-  PangoLayoutLine *line, *prev_line = NULL;
-  gint index, start_index, end_index;
-  const gchar *text;
-  gboolean found = FALSE;
-
-  text = pango_layout_get_text (layout);
-  index = g_utf8_offset_to_pointer (text, offset) - text;
-  iter = pango_layout_get_iter (layout);
-  do
-    {
-      line = pango_layout_iter_get_line (iter);
-      start_index = line->start_index;
-      end_index = start_index + line->length;
-
-      if (index >= start_index && index <= end_index)
-        {
-          /* Found line for offset */
-          if (pango_layout_iter_next_line (iter))
-            {
-              line = pango_layout_iter_get_line (iter);
-              switch (boundary_type)
-                {
-                case ATK_TEXT_BOUNDARY_LINE_START:
-                  start_index = line->start_index;
-                  if (pango_layout_iter_next_line (iter))
-                    end_index = pango_layout_iter_get_line (iter)->start_index;
-                  else
-                    end_index = start_index + line->length;
-                  break;
-                case ATK_TEXT_BOUNDARY_LINE_END:
-                  start_index = end_index;
-                  end_index = line->start_index + line->length;
-                  break;
-                default:
-                  g_assert_not_reached();
-                }
-            }
-          else
-            start_index = end_index;
-
-          found = TRUE;
-          break;
-        }
-
-      prev_line = line;
-    }
-  while (pango_layout_iter_next_line (iter));
-
-  if (!found)
-    {
-      start_index = prev_line->start_index + prev_line->length;
-      end_index = start_index;
-    }
-  pango_layout_iter_free (iter);
-
-  *start_offset = g_utf8_pointer_to_offset (text, text + start_index);
-  *end_offset = g_utf8_pointer_to_offset (text, text + end_index);
-}
-
-/*
- * _gtk_pango_get_text_at:
- * @layout: a #PangoLayout
- * @boundary_type: a #AtkTextBoundary
- * @offset: a character offset in @layout
- * @start_offset: return location for the start of the returned text
- * @end_offset: return location for the end of the return text
- *
- * Gets a slice of the text from @layout at @offset.
- *
- * The @boundary_type determines the size of the returned slice of
- * text. For the exact semantics of this function, see
- * atk_text_get_text_after_offset().
- *
- * Returns: a newly allocated string containing a slice of text
- *     from layout. Free with g_free().
- */
-static gchar *
-_gtk_pango_get_text_at (PangoLayout     *layout,
-                        AtkTextBoundary  boundary_type,
-                        gint             offset,
-                        gint            *start_offset,
-                        gint            *end_offset)
-{
-  const gchar *text;
-  gint start, end;
-  const PangoLogAttr *attrs;
-  gint n_attrs;
-
-  text = pango_layout_get_text (layout);
-
-  if (text[0] == 0)
-    {
-      *start_offset = 0;
-      *end_offset = 0;
-      return g_strdup ("");
-    }
-
-  attrs = pango_layout_get_log_attrs_readonly (layout, &n_attrs);
-
-  start = offset;
-  end = start;
-
-  switch (boundary_type)
-    {
-    case ATK_TEXT_BOUNDARY_CHAR:
-      end = _gtk_pango_move_chars (layout, end, 1);
-      break;
-
-    case ATK_TEXT_BOUNDARY_WORD_START:
-      if (!attrs[start].is_word_start)
-        start = _gtk_pango_move_words (layout, start, -1);
-      if (_gtk_pango_is_inside_word (layout, end))
-        end = _gtk_pango_move_words (layout, end, 1);
-      while (!attrs[end].is_word_start && end < n_attrs - 1)
-        end = _gtk_pango_move_chars (layout, end, 1);
-      break;
-
-    case ATK_TEXT_BOUNDARY_WORD_END:
-      if (_gtk_pango_is_inside_word (layout, start) &&
-          !attrs[start].is_word_start)
-        start = _gtk_pango_move_words (layout, start, -1);
-      while (!attrs[start].is_word_end && start > 0)
-        start = _gtk_pango_move_chars (layout, start, -1);
-      end = _gtk_pango_move_words (layout, end, 1);
-      break;
-
-    case ATK_TEXT_BOUNDARY_SENTENCE_START:
-      if (!attrs[start].is_sentence_start)
-        start = _gtk_pango_move_sentences (layout, start, -1);
-      if (_gtk_pango_is_inside_sentence (layout, end))
-        end = _gtk_pango_move_sentences (layout, end, 1);
-      while (!attrs[end].is_sentence_start && end < n_attrs - 1)
-        end = _gtk_pango_move_chars (layout, end, 1);
-      break;
-
-    case ATK_TEXT_BOUNDARY_SENTENCE_END:
-      if (_gtk_pango_is_inside_sentence (layout, start) &&
-          !attrs[start].is_sentence_start)
-        start = _gtk_pango_move_sentences (layout, start, -1);
-      while (!attrs[start].is_sentence_end && start > 0)
-        start = _gtk_pango_move_chars (layout, start, -1);
-      end = _gtk_pango_move_sentences (layout, end, 1);
-      break;
-
-    case ATK_TEXT_BOUNDARY_LINE_START:
-    case ATK_TEXT_BOUNDARY_LINE_END:
-      pango_layout_get_line_at (layout, boundary_type, offset, &start, &end);
-      break;
-    }
-
-  *start_offset = start;
-  *end_offset = end;
-
-  g_assert (start <= end);
-
-  return g_utf8_substring (text, start, end);
-}
-
-/*
- * _gtk_pango_get_text_before:
- * @layout: a #PangoLayout
- * @boundary_type: a #AtkTextBoundary
- * @offset: a character offset in @layout
- * @start_offset: return location for the start of the returned text
- * @end_offset: return location for the end of the return text
- *
- * Gets a slice of the text from @layout before @offset.
- *
- * The @boundary_type determines the size of the returned slice of
- * text. For the exact semantics of this function, see
- * atk_text_get_text_before_offset().
- *
- * Returns: a newly allocated string containing a slice of text
- *     from layout. Free with g_free().
- */
-static gchar *
-_gtk_pango_get_text_before (PangoLayout     *layout,
-                            AtkTextBoundary  boundary_type,
-                            gint             offset,
-                            gint            *start_offset,
-                            gint            *end_offset)
-{
-  const gchar *text;
-  gint start, end;
-  const PangoLogAttr *attrs;
-  gint n_attrs;
-
-  text = pango_layout_get_text (layout);
-
-  if (text[0] == 0)
-    {
-      *start_offset = 0;
-      *end_offset = 0;
-      return g_strdup ("");
-    }
-
-  attrs = pango_layout_get_log_attrs_readonly (layout, &n_attrs);
-
-  start = offset;
-  end = start;
-
-  switch (boundary_type)
-    {
-    case ATK_TEXT_BOUNDARY_CHAR:
-      start = _gtk_pango_move_chars (layout, start, -1);
-      break;
-
-    case ATK_TEXT_BOUNDARY_WORD_START:
-      if (!attrs[start].is_word_start)
-        start = _gtk_pango_move_words (layout, start, -1);
-      end = start;
-      start = _gtk_pango_move_words (layout, start, -1);
-      break;
-
-    case ATK_TEXT_BOUNDARY_WORD_END:
-      if (_gtk_pango_is_inside_word (layout, start) &&
-          !attrs[start].is_word_start)
-        start = _gtk_pango_move_words (layout, start, -1);
-      while (!attrs[start].is_word_end && start > 0)
-        start = _gtk_pango_move_chars (layout, start, -1);
-      end = start;
-      start = _gtk_pango_move_words (layout, start, -1);
-      while (!attrs[start].is_word_end && start > 0)
-        start = _gtk_pango_move_chars (layout, start, -1);
-      break;
-
-    case ATK_TEXT_BOUNDARY_SENTENCE_START:
-      if (!attrs[start].is_sentence_start)
-        start = _gtk_pango_move_sentences (layout, start, -1);
-      end = start;
-      start = _gtk_pango_move_sentences (layout, start, -1);
-      break;
-
-    case ATK_TEXT_BOUNDARY_SENTENCE_END:
-      if (_gtk_pango_is_inside_sentence (layout, start) &&
-          !attrs[start].is_sentence_start)
-        start = _gtk_pango_move_sentences (layout, start, -1);
-      while (!attrs[start].is_sentence_end && start > 0)
-        start = _gtk_pango_move_chars (layout, start, -1);
-      end = start;
-      start = _gtk_pango_move_sentences (layout, start, -1);
-      while (!attrs[start].is_sentence_end && start > 0)
-        start = _gtk_pango_move_chars (layout, start, -1);
-      break;
-
-    case ATK_TEXT_BOUNDARY_LINE_START:
-    case ATK_TEXT_BOUNDARY_LINE_END:
-      pango_layout_get_line_before (layout, boundary_type, offset, &start, &end);
-      break;
-    }
-
-  *start_offset = start;
-  *end_offset = end;
-
-  g_assert (start <= end);
-
-  return g_utf8_substring (text, start, end);
-}
-
-/*
- * _gtk_pango_get_text_after:
- * @layout: a #PangoLayout
- * @boundary_type: a #AtkTextBoundary
- * @offset: a character offset in @layout
- * @start_offset: return location for the start of the returned text
- * @end_offset: return location for the end of the return text
- *
- * Gets a slice of the text from @layout after @offset.
- *
- * The @boundary_type determines the size of the returned slice of
- * text. For the exact semantics of this function, see
- * atk_text_get_text_after_offset().
- *
- * Returns: a newly allocated string containing a slice of text
- *     from layout. Free with g_free().
- */
-static gchar *
-_gtk_pango_get_text_after (PangoLayout     *layout,
-                           AtkTextBoundary  boundary_type,
-                           gint             offset,
-                           gint            *start_offset,
-                           gint            *end_offset)
-{
-  const gchar *text;
-  gint start, end;
-  const PangoLogAttr *attrs;
-  gint n_attrs;
-
-  text = pango_layout_get_text (layout);
-
-  if (text[0] == 0)
-    {
-      *start_offset = 0;
-      *end_offset = 0;
-      return g_strdup ("");
-    }
-
-  attrs = pango_layout_get_log_attrs_readonly (layout, &n_attrs);
-
-  start = offset;
-  end = start;
-
-  switch (boundary_type)
-    {
-    case ATK_TEXT_BOUNDARY_CHAR:
-      start = _gtk_pango_move_chars (layout, start, 1);
-      end = start;
-      end = _gtk_pango_move_chars (layout, end, 1);
-      break;
-
-    case ATK_TEXT_BOUNDARY_WORD_START:
-      if (_gtk_pango_is_inside_word (layout, end))
-        end = _gtk_pango_move_words (layout, end, 1);
-      while (!attrs[end].is_word_start && end < n_attrs - 1)
-        end = _gtk_pango_move_chars (layout, end, 1);
-      start = end;
-      if (end < n_attrs - 1)
-        {
-          end = _gtk_pango_move_words (layout, end, 1);
-          while (!attrs[end].is_word_start && end < n_attrs - 1)
-            end = _gtk_pango_move_chars (layout, end, 1);
-        }
-      break;
-
-    case ATK_TEXT_BOUNDARY_WORD_END:
-      end = _gtk_pango_move_words (layout, end, 1);
-      start = end;
-      if (end < n_attrs - 1)
-        end = _gtk_pango_move_words (layout, end, 1);
-      break;
-
-    case ATK_TEXT_BOUNDARY_SENTENCE_START:
-      if (_gtk_pango_is_inside_sentence (layout, end))
-        end = _gtk_pango_move_sentences (layout, end, 1);
-      while (!attrs[end].is_sentence_start && end < n_attrs - 1)
-        end = _gtk_pango_move_chars (layout, end, 1);
-      start = end;
-      if (end < n_attrs - 1)
-        {
-          end = _gtk_pango_move_sentences (layout, end, 1);
-          while (!attrs[end].is_sentence_start && end < n_attrs - 1)
-            end = _gtk_pango_move_chars (layout, end, 1);
-        }
-      break;
-
-    case ATK_TEXT_BOUNDARY_SENTENCE_END:
-      end = _gtk_pango_move_sentences (layout, end, 1);
-      start = end;
-      if (end < n_attrs - 1)
-        end = _gtk_pango_move_sentences (layout, end, 1);
-      break;
-
-    case ATK_TEXT_BOUNDARY_LINE_START:
-    case ATK_TEXT_BOUNDARY_LINE_END:
-      pango_layout_get_line_after (layout, boundary_type, offset, &start, &end);
-      break;
-    }
-
-  *start_offset = start;
-  *end_offset = end;
-
-  g_assert (start <= end);
-
-  return g_utf8_substring (text, start, end);
-}
 
 /***** atktext.h ******/
 
@@ -1073,28 +429,13 @@ cally_text_get_text (AtkText *text,
                      gint end_offset)
 {
   ClutterActor *actor = NULL;
-  PangoLayout *layout = NULL;
-  const gchar *string = NULL;
-  gint character_count = 0;
 
   actor = CALLY_GET_CLUTTER_ACTOR (text);
   if (actor == NULL) /* Object is defunct */
     return NULL;
 
-  /* we use the pango layout instead of clutter_text_get_chars because
-     it take into account password-char */
-
-  layout = clutter_text_get_layout (CLUTTER_TEXT (actor));
-  string = pango_layout_get_text (layout);
-  character_count = pango_layout_get_character_count (layout);
-
-  if (end_offset == -1 || end_offset > character_count)
-    end_offset = character_count;
-
-  if (string[0] == 0)
-    return g_strdup("");
-  else
-    return g_utf8_substring (string, start_offset, end_offset);
+  return clutter_text_get_chars (CLUTTER_TEXT (actor),
+                                 start_offset, end_offset);
 }
 
 static gunichar
@@ -1102,21 +443,15 @@ cally_text_get_character_at_offset (AtkText *text,
                                     gint     offset)
 {
   ClutterActor *actor      = NULL;
-  const gchar  *string     = NULL;
+  gchar        *string     = NULL;
   gchar        *index      = NULL;
   gunichar      unichar;
-  PangoLayout  *layout = NULL;
 
   actor = CALLY_GET_CLUTTER_ACTOR (text);
   if (actor == NULL) /* State is defunct */
     return '\0';
 
-  /* we use the pango layout instead of clutter_text_get_chars because
-     it take into account password-char */
-
-  layout = clutter_text_get_layout (CLUTTER_TEXT (actor));
-  string = pango_layout_get_text (layout);
-
+  string = clutter_text_get_chars (CLUTTER_TEXT (actor), 0, -1);
   if (offset >= g_utf8_strlen (string, -1))
     {
       unichar = '\0';
@@ -1125,9 +460,11 @@ cally_text_get_character_at_offset (AtkText *text,
     {
       index = g_utf8_offset_to_pointer (string, offset);
 
-      unichar = g_utf8_get_char (index);
+      unichar = g_utf8_get_char(index);
     }
 
+  g_free(string);
+
   return unichar;
 }
 
@@ -1139,14 +476,28 @@ cally_text_get_text_before_offset (AtkText	    *text,
 				   gint		    *end_offset)
 {
   ClutterActor *actor        = NULL;
+#if 0
+  ClutterText  *clutter_text = NULL;
+  CallyText    *cally_text   = NULL;
+#endif
 
   actor = CALLY_GET_CLUTTER_ACTOR (text);
   if (actor == NULL) /* State is defunct */
     return NULL;
 
-  return _gtk_pango_get_text_before (clutter_text_get_layout (CLUTTER_TEXT (actor)),
-                                     boundary_type, offset,
-                                     start_offset, end_offset);
+#if 0
+  clutter_text = CLUTTER_TEXT (actor);
+  cally_text = CALLY_TEXT (text);
+
+  return gail_text_util_get_text (cally_text->priv->textutil,
+                                  clutter_text_get_layout (clutter_text),
+                                  GAIL_BEFORE_OFFSET,
+                                  boundary_type,
+                                  offset,
+                                  start_offset, end_offset);
+#endif
+
+  return NULL;
 }
 
 static gchar*
@@ -1157,14 +508,28 @@ cally_text_get_text_at_offset (AtkText         *text,
                                gint            *end_offset)
 {
   ClutterActor *actor        = NULL;
+#if 0
+  ClutterText  *clutter_text = NULL;
+  CallyText    *cally_text   = NULL;
+#endif
 
   actor = CALLY_GET_CLUTTER_ACTOR (text);
   if (actor == NULL) /* State is defunct */
     return NULL;
 
-  return _gtk_pango_get_text_at (clutter_text_get_layout (CLUTTER_TEXT (actor)),
-                                 boundary_type, offset,
-                                 start_offset, end_offset);
+#if 0
+  clutter_text = CLUTTER_TEXT (actor);
+  cally_text = CALLY_TEXT (text);
+
+  return gail_text_util_get_text (cally_text->priv->textutil,
+                                  clutter_text_get_layout (clutter_text),
+                                  GAIL_AT_OFFSET,
+                                  boundary_type,
+                                  offset,
+                                  start_offset, end_offset);
+#endif
+
+  return NULL;
 }
 
 static gchar*
@@ -1175,14 +540,28 @@ cally_text_get_text_after_offset (AtkText         *text,
                                   gint            *end_offset)
 {
   ClutterActor *actor        = NULL;
+#if 0
+  ClutterText  *clutter_text = NULL;
+  CallyText    *cally_text   = NULL;
+#endif
 
   actor = CALLY_GET_CLUTTER_ACTOR (text);
   if (actor == NULL) /* State is defunct */
     return NULL;
 
-  return _gtk_pango_get_text_after (clutter_text_get_layout (CLUTTER_TEXT (actor)),
-                                    boundary_type, offset,
-                                    start_offset, end_offset);
+#if 0
+  clutter_text = CLUTTER_TEXT (actor);
+  cally_text = CALLY_TEXT (text);
+
+  return gail_text_util_get_text (cally_text->priv->textutil,
+                                  clutter_text_get_layout (clutter_text),
+                                  GAIL_AFTER_OFFSET,
+                                  boundary_type,
+                                  offset,
+                                  start_offset, end_offset);
+#endif
+
+  return NULL;
 }
 
 static gint
@@ -1233,7 +612,6 @@ cally_text_get_n_selections (AtkText *text)
 {
   ClutterActor *actor           = NULL;
   gint          selection_bound = -1;
-  gint          cursor_position = -1;
 
   actor = CALLY_GET_CLUTTER_ACTOR (text);
   if (actor == NULL) /* State is defunct */
@@ -1243,12 +621,11 @@ cally_text_get_n_selections (AtkText *text)
     return 0;
 
   selection_bound = clutter_text_get_selection_bound (CLUTTER_TEXT (actor));
-  cursor_position = clutter_text_get_cursor_position (CLUTTER_TEXT (actor));
 
-  if (selection_bound == cursor_position)
-    return 0;
-  else
+  if (selection_bound > 0)
     return 1;
+  else
+    return 0;
 }
 
 static gchar*
@@ -1612,6 +989,7 @@ cally_text_editable_text_interface_init (AtkEditableTextIface *iface)
   iface->insert_text = cally_text_insert_text;
   iface->delete_text = cally_text_delete_text;
 
+  /* Not implemented, see IMPLEMENTATION NOTES*/
   iface->set_run_attributes = NULL;
   iface->copy_text = NULL;
   iface->cut_text = NULL;
