@@ -269,6 +269,14 @@ clutter_backend_real_create_context (ClutterBackend  *backend,
   if (backend->cogl_renderer == NULL)
     goto error;
 
+#ifdef HAVE_CLUTTER_WAYLAND_COMPOSITOR
+  /* If the application is trying to act as a Wayland compositor then
+     it needs to have an EGL-based renderer backend */
+  if (_wayland_compositor_display)
+    cogl_renderer_add_constraint (backend->cogl_renderer,
+                                  COGL_RENDERER_CONSTRAINT_USES_EGL);
+#endif
+
   CLUTTER_NOTE (BACKEND, "Connecting the renderer");
   if (!cogl_renderer_connect (backend->cogl_renderer, &internal_error))
     goto error;
@@ -1029,7 +1037,7 @@ clutter_backend_get_double_click_distance (ClutterBackend *backend)
  *
  * Since: 0.4
  *
- * Deprecated: Use #ClutterSettings:font-dpi instead
+ * Deprecated: 1.4: Use #ClutterSettings:font-dpi instead
  */
 void
 clutter_backend_set_resolution (ClutterBackend *backend,
