@@ -80,7 +80,7 @@
  * <example id="bind-constraint-example">
  *   <title>Animating the offset property of ClutterBindConstraint</title>
  *   <programlisting>
- * <xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" href="../../../../tests/interactive/test-bind-constraint.c">
+ * <xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" href="../../../../tests/interactive/test-constraints.c">
  *   <xi:fallback>FIXME: MISSING XINCLUDE CONTENT</xi:fallback>
  * </xi:include>
  *   </programlisting>
@@ -151,7 +151,7 @@ source_queue_relayout (ClutterActor          *source,
                        ClutterBindConstraint *bind)
 {
   if (bind->actor != NULL)
-    _clutter_actor_queue_only_relayout (bind->actor);
+    clutter_actor_queue_relayout (bind->actor);
 }
 
 static void
@@ -223,8 +223,6 @@ clutter_bind_constraint_update_allocation (ClutterConstraint *constraint,
       g_assert_not_reached ();
       break;
     }
-
-  clutter_actor_box_clamp_to_pixel (allocation);
 }
 
 static void
