@@ -33,7 +33,6 @@
 #define __CLUTTER_CAIRO_TEXTURE_H__
 
 #include <clutter/clutter-texture.h>
-#include <cairo.h>
 
 G_BEGIN_DECLS
 
@@ -116,15 +115,6 @@ GType clutter_cairo_texture_get_type (void) G_GNUC_CONST;
 ClutterActor *  clutter_cairo_texture_new                       (guint                  width,
                                                                  guint                  height);
 
-#ifndef CLUTTER_DISABLE_DEPRECATED
-cairo_t *       clutter_cairo_texture_create_region             (ClutterCairoTexture   *self,
-                                                                 gint                   x_offset,
-                                                                 gint                   y_offset,
-                                                                 gint                   width,
-                                                                 gint                   height);
-cairo_t *       clutter_cairo_texture_create                    (ClutterCairoTexture   *self);
-#endif /* CLUTTER_DISABLE_DEPRECATED */
-
 void            clutter_cairo_texture_set_surface_size          (ClutterCairoTexture   *self,
                                                                  guint                  width,
                                                                  guint                  height);
