@@ -44,7 +44,7 @@
 #define CLUTTER_FLAVOUR         "deprecated"
 
 /**
- * CLUTTER_COGL:
+ * CLUTTER_COGL
  *
  * Cogl (internal GL abstraction utility library) backend. Can be "gl" or
  * "gles" currently
@@ -75,7 +75,7 @@
  *
  * Set to 1 if Clutter was built without FPU (i.e fixed math), 0 otherwise
  *
- * Deprecated: 0.6: This macro is no longer defined (identical code is used
+ * @Deprecated: 0.6: This macro is no longer defined (identical code is used
  *  regardless the presence of FPU).
  */
 #define CLUTTER_NO_FPU          (0)
@@ -126,7 +126,7 @@
  * Since: 1.10
  */
 #ifndef CLUTTER_VERSION_MIN_REQUIRED
-# define CLUTTER_VERSION_MIN_REQUIRED   (CLUTTER_VERSION_CUR_STABLE)
+# define CLUTTER_VERSION_MIN_REQUIRED   (CLUTTER_VERSION_PREV_STABLE)
 #endif
 
 /**
@@ -248,46 +248,4 @@
 # define CLUTTER_AVAILABLE_IN_1_10
 #endif
 
-#if CLUTTER_VERSION_MIN_REQUIRED >= CLUTTER_VERSION_1_12
-# define CLUTTER_DEPRECATED_IN_1_12             CLUTTER_DEPRECATED
-# define CLUTTER_DEPRECATED_IN_1_12_FOR(f)      CLUTTER_DEPRECATED_FOR(f)
-#else
-# define CLUTTER_DEPRECATED_IN_1_12
-# define CLUTTER_DEPRECATED_IN_1_12_FOR(f)
-#endif
-
-#if CLUTTER_VERSION_MAX_ALLOWED < CLUTTER_VERSION_1_12
-# define CLUTTER_AVAILABLE_IN_1_12              CLUTTER_UNAVAILABLE(1, 12)
-#else
-# define CLUTTER_AVAILABLE_IN_1_12
-#endif
-
-#if CLUTTER_VERSION_MIN_REQUIRED >= CLUTTER_VERSION_1_14
-# define CLUTTER_DEPRECATED_IN_1_14             CLUTTER_DEPRECATED
-# define CLUTTER_DEPRECATED_IN_1_14_FOR(f)      CLUTTER_DEPRECATED_FOR(f)
-#else
-# define CLUTTER_DEPRECATED_IN_1_14
-# define CLUTTER_DEPRECATED_IN_1_14_FOR(f)
-#endif
-
-#if CLUTTER_VERSION_MAX_ALLOWED < CLUTTER_VERSION_1_14
-# define CLUTTER_AVAILABLE_IN_1_14              CLUTTER_UNAVAILABLE(1, 14)
-#else
-# define CLUTTER_AVAILABLE_IN_1_14
-#endif
-
-#if CLUTTER_VERSION_MIN_REQUIRED >= CLUTTER_VERSION_1_16
-# define CLUTTER_DEPRECATED_IN_1_16             CLUTTER_DEPRECATED
-# define CLUTTER_DEPRECATED_IN_1_16_FOR(f)      CLUTTER_DEPRECATED_FOR(f)
-#else
-# define CLUTTER_DEPRECATED_IN_1_16
-# define CLUTTER_DEPRECATED_IN_1_16_FOR(f)
-#endif
-
-#if CLUTTER_VERSION_MAX_ALLOWED < CLUTTER_VERSION_1_16
-# define CLUTTER_AVAILABLE_IN_1_16              CLUTTER_UNAVAILABLE(1, 16)
-#else
-# define CLUTTER_AVAILABLE_IN_1_16
-#endif
-
 #endif /* __CLUTTER_MACROS_H__ */
