@@ -63,11 +63,18 @@ struct _ClutterDeviceManagerEvdevPrivate
 {
   GUdevClient *udev_client;
 
+  ClutterStage *stage;
+  gboolean released;
+
   GSList *devices;          /* list of ClutterInputDeviceEvdevs */
   GSList *event_sources;    /* list of the event sources */
 
   ClutterInputDevice *core_pointer;
   ClutterInputDevice *core_keyboard;
+
+  ClutterStageManager *stage_manager;
+  guint stage_added_handler;
+  guint stage_removed_handler;
 };
 
 static const gchar *subsystems[] = { "input", NULL };
@@ -589,6 +596,8 @@ evdev_add_device (ClutterDeviceManagerEvdev *manager_evdev,
                          "enabled", TRUE,
                          NULL);
 
+  _clutter_input_device_set_stage (device, manager_evdev->priv->stage);
+
   _clutter_device_manager_add_device (manager, device);
 
   CLUTTER_NOTE (EVENT, "Added device %s, type %d, sysfs %s",
@@ -647,6 +656,10 @@ on_uevent (GUdevClient *client,
            gpointer     data)
 {
   ClutterDeviceManagerEvdev *manager = CLUTTER_DEVICE_MANAGER_EVDEV (data);
+  ClutterDeviceManagerEvdevPrivate *priv = manager->priv;
+
+  if (priv->released)
+    return;
 
   if (g_strcmp0 (action, "add") == 0)
     evdev_add_device (manager, device);
@@ -772,6 +785,23 @@ clutter_device_manager_evdev_get_device (ClutterDeviceManager *manager,
   return NULL;
 }
 
+static void
+clutter_device_manager_evdev_probe_devices (ClutterDeviceManagerEvdev *self)
+{
+  ClutterDeviceManagerEvdevPrivate *priv = self->priv;
+  GList *devices, *l;
+
+  devices = g_udev_client_query_by_subsystem (priv->udev_client, subsystems[0]);
+  for (l = devices; l; l = g_list_next (l))
+    {
+      GUdevDevice *device = l->data;
+
+      evdev_add_device (self, device);
+      g_object_unref (device);
+    }
+  g_list_free (devices);
+}
+
 /*
  * GObject implementation
  */
@@ -781,28 +811,51 @@ clutter_device_manager_evdev_constructed (GObject *gobject)
 {
   ClutterDeviceManagerEvdev *manager_evdev;
   ClutterDeviceManagerEvdevPrivate *priv;
-  GList *devices, *l;
 
   manager_evdev = CLUTTER_DEVICE_MANAGER_EVDEV (gobject);
   priv = manager_evdev->priv;
 
   priv->udev_client = g_udev_client_new (subsystems);
 
-  devices = g_udev_client_query_by_subsystem (priv->udev_client, subsystems[0]);
-  for (l = devices; l; l = g_list_next (l))
-    {
-      GUdevDevice *device = l->data;
-
-      evdev_add_device (manager_evdev, device);
-      g_object_unref (device);
-    }
-  g_list_free (devices);
+  clutter_device_manager_evdev_probe_devices (manager_evdev);
 
   /* subcribe for events on input devices */
   g_signal_connect (priv->udev_client, "uevent",
                     G_CALLBACK (on_uevent), manager_evdev);
 }
 
+static void
+clutter_device_manager_evdev_dispose (GObject *object)
+{
+  ClutterDeviceManagerEvdev *manager_evdev;
+  ClutterDeviceManagerEvdevPrivate *priv;
+
+  manager_evdev = CLUTTER_DEVICE_MANAGER_EVDEV (object);
+  priv = manager_evdev->priv;
+
+  if (priv->stage_added_handler)
+    {
+      g_signal_handler_disconnect (priv->stage_manager,
+                                   priv->stage_added_handler);
+      priv->stage_added_handler = 0;
+    }
+
+  if (priv->stage_removed_handler)
+    {
+      g_signal_handler_disconnect (priv->stage_manager,
+                                   priv->stage_removed_handler);
+      priv->stage_removed_handler = 0;
+    }
+
+  if (priv->stage_manager)
+    {
+      g_object_unref (priv->stage_manager);
+      priv->stage_manager = NULL;
+    }
+
+  G_OBJECT_CLASS (clutter_device_manager_evdev_parent_class)->dispose (object);
+}
+
 static void
 clutter_device_manager_evdev_finalize (GObject *object)
 {
@@ -844,6 +897,7 @@ clutter_device_manager_evdev_class_init (ClutterDeviceManagerEvdevClass *klass)
 
   gobject_class->constructed = clutter_device_manager_evdev_constructed;
   gobject_class->finalize = clutter_device_manager_evdev_finalize;
+  gobject_class->dispose = clutter_device_manager_evdev_dispose;
 
   manager_class = CLUTTER_DEVICE_MANAGER_CLASS (klass);
   manager_class->add_device = clutter_device_manager_evdev_add_device;
@@ -853,10 +907,86 @@ clutter_device_manager_evdev_class_init (ClutterDeviceManagerEvdevClass *klass)
   manager_class->get_device = clutter_device_manager_evdev_get_device;
 }
 
+static void
+clutter_device_manager_evdev_stage_added_cb (ClutterStageManager *manager,
+                                             ClutterStage *stage,
+                                             ClutterDeviceManagerEvdev *self)
+{
+  ClutterDeviceManagerEvdevPrivate *priv = self->priv;
+  GSList *l;
+
+  /* NB: Currently we can only associate a single stage with all evdev
+   * devices.
+   *
+   * We save a pointer to the stage so if we release/reclaim input
+   * devices due to switching virtual terminals then we know what
+   * stage to re associate the devices with.
+   */
+  priv->stage = stage;
+
+  /* Set the stage of any devices that don't already have a stage */
+  for (l = priv->devices; l; l = l->next)
+    {
+      ClutterInputDevice *device = l->data;
+
+      if (_clutter_input_device_get_stage (device) == NULL)
+        _clutter_input_device_set_stage (device, stage);
+    }
+
+  /* We only want to do this once so we can catch the default
+     stage. If the application has multiple stages then it will need
+     to manage the stage of the input devices itself */
+  g_signal_handler_disconnect (priv->stage_manager,
+                               priv->stage_added_handler);
+  priv->stage_added_handler = 0;
+}
+
+static void
+clutter_device_manager_evdev_stage_removed_cb (ClutterStageManager *manager,
+                                               ClutterStage *stage,
+                                               ClutterDeviceManagerEvdev *self)
+{
+  ClutterDeviceManagerEvdevPrivate *priv = self->priv;
+  GSList *l;
+
+  /* Remove the stage of any input devices that were pointing to this
+     stage so we don't send events to invalid stages */
+  for (l = priv->devices; l; l = l->next)
+    {
+      ClutterInputDevice *device = l->data;
+
+      if (_clutter_input_device_get_stage (device) == stage)
+        _clutter_input_device_set_stage (device, NULL);
+    }
+}
+
 static void
 clutter_device_manager_evdev_init (ClutterDeviceManagerEvdev *self)
 {
-  self->priv = CLUTTER_DEVICE_MANAGER_EVDEV_GET_PRIVATE (self);
+  ClutterDeviceManagerEvdevPrivate *priv;
+
+  priv = self->priv = CLUTTER_DEVICE_MANAGER_EVDEV_GET_PRIVATE (self);
+
+  priv->stage_manager = clutter_stage_manager_get_default ();
+  g_object_ref (priv->stage_manager);
+
+  /* evdev doesn't have any way to link an event to a particular stage
+     so we'll have to leave it up to applications to set the
+     corresponding stage for an input device. However to make it
+     easier for applications that are only using one fullscreen stage
+     (which is probably the most frequent use-case for the evdev
+     backend) we'll associate any input devices that don't have a
+     stage with the first stage created. */
+  priv->stage_added_handler =
+    g_signal_connect (priv->stage_manager,
+                      "stage-added",
+                      G_CALLBACK (clutter_device_manager_evdev_stage_added_cb),
+                      self);
+  priv->stage_removed_handler =
+    g_signal_connect (priv->stage_manager,
+                      "stage-removed",
+                      G_CALLBACK (clutter_device_manager_evdev_stage_removed_cb),
+                      self);
 }
 
 void
@@ -874,3 +1004,101 @@ _clutter_events_evdev_uninit (ClutterBackend *backend)
 {
   CLUTTER_NOTE (EVENT, "Uninitializing evdev backend");
 }
+
+/**
+ * clutter_evdev_release_devices:
+ *
+ * Releases all the evdev devices that Clutter is currently managing. This api
+ * is typically used when switching away from the Clutter application when
+ * switching tty. The devices can be reclaimed later with a call to
+ * clutter_evdev_reclaim_devices().
+ *
+ * This function should only be called after clutter has been initialized.
+ *
+ * Since: 1.10
+ * Stability: unstable
+ */
+void
+clutter_evdev_release_devices (void)
+{
+  ClutterDeviceManager *manager = clutter_device_manager_get_default ();
+  ClutterDeviceManagerEvdev *evdev_manager;
+  ClutterDeviceManagerEvdevPrivate *priv;
+  GSList *l, *next;
+
+  if (!manager)
+    {
+      g_warning ("clutter_evdev_release_devices shouldn't be called "
+                 "before clutter_init()");
+      return;
+    }
+
+  g_return_if_fail (CLUTTER_IS_DEVICE_MANAGER_EVDEV (manager));
+
+  evdev_manager = CLUTTER_DEVICE_MANAGER_EVDEV (manager);
+  priv = evdev_manager->priv;
+
+  if (priv->released)
+    {
+      g_warning ("clutter_evdev_release_devices() shouldn't be called "
+                 "multiple times without a corresponding call to "
+                 "clutter_evdev_reclaim_devices() first");
+      return;
+    }
+
+  for (l = priv->devices; l; l = next)
+    {
+      ClutterInputDevice *device = l->data;
+
+      /* Be careful about the list we're iterating being modified... */
+      next = l->next;
+
+      _clutter_device_manager_remove_device (manager, device);
+    }
+
+  priv->released = TRUE;
+}
+
+/**
+ * clutter_evdev_reclaim_devices:
+ *
+ * This causes Clutter to re-probe for evdev devices. This is must only be
+ * called after a corresponding call to clutter_evdev_release_devices()
+ * was previously used to release all evdev devices. This API is typically
+ * used when a clutter application using evdev has regained focus due to
+ * switching ttys.
+ *
+ * This function should only be called after clutter has been initialized.
+ *
+ * Since: 1.10
+ * Stability: unstable
+ */
+void
+clutter_evdev_reclaim_devices (void)
+{
+  ClutterDeviceManager *manager = clutter_device_manager_get_default ();
+  ClutterDeviceManagerEvdev *evdev_manager;
+  ClutterDeviceManagerEvdevPrivate *priv;
+
+  if (!manager)
+    {
+      g_warning ("clutter_evdev_reclaim_devices shouldn't be called "
+                 "before clutter_init()");
+      return;
+    }
+
+  g_return_if_fail (CLUTTER_IS_DEVICE_MANAGER_EVDEV (manager));
+
+  evdev_manager = CLUTTER_DEVICE_MANAGER_EVDEV (manager);
+  priv = evdev_manager->priv;
+
+  if (!priv->released)
+    {
+      g_warning ("Spurious call to clutter_evdev_reclaim_devices() without "
+                 "previous call to clutter_evdev_release_devices");
+      return;
+    }
+
+  priv->released = FALSE;
+  clutter_device_manager_evdev_probe_devices (evdev_manager);
+}
