@@ -26,10 +26,6 @@
 
 #include "clutter-input-device-gdk.h"
 
-#ifdef GDK_WINDOWING_X11
-#include <gdk/gdkx.h>
-#endif
-
 #include "clutter-debug.h"
 #include "clutter-device-manager-private.h"
 #include "clutter-private.h"
@@ -105,9 +101,6 @@ _clutter_input_device_gdk_new (ClutterDeviceManager    *manager,
   gboolean has_cursor = FALSE;
   const gchar *name;
   gboolean is_enabled = FALSE;
-  gint device_id;
-  const char *vendor_id = NULL;
-  const char *product_id = NULL;
 
   g_object_get (manager, "backend", &backend, NULL);
 
@@ -145,18 +138,6 @@ _clutter_input_device_gdk_new (ClutterDeviceManager    *manager,
     case GDK_SOURCE_KEYBOARD:
       device_type = CLUTTER_KEYBOARD_DEVICE;
       break;
-    case GDK_SOURCE_TOUCHSCREEN:
-      device_type = CLUTTER_TOUCHSCREEN_DEVICE;
-      break;
-    case GDK_SOURCE_TOUCHPAD:
-      device_type = CLUTTER_TOUCHPAD_DEVICE;
-      break;
-    case GDK_SOURCE_TRACKPOINT:
-      device_type = CLUTTER_POINTER_DEVICE;
-      break;
-    case GDK_SOURCE_TABLET_PAD:
-      device_type = CLUTTER_CURSOR_DEVICE;
-      break;
     }
 
   if (device_type != CLUTTER_KEYBOARD_DEVICE)
@@ -164,20 +145,6 @@ _clutter_input_device_gdk_new (ClutterDeviceManager    *manager,
 
   name = gdk_device_get_name (device);
 
-#if defined(GDK_WINDOWING_X11)
-  /* If we're on X11, keep the device id in sync */
-  if (GDK_IS_X11_DISPLAY (gdk_device_get_display (device)))
-    device_id = gdk_x11_device_get_id (device);
-  else
-#endif
-    device_id = device_int_counter++;
-
-  if (gdk_device_get_device_type (device) != GDK_DEVICE_TYPE_MASTER)
-    {
-      product_id = gdk_device_get_product_id (device);
-      vendor_id = gdk_device_get_vendor_id (device);
-    }
-
   clutter_device = g_object_new (CLUTTER_TYPE_INPUT_DEVICE_GDK,
 				 "backend", backend,
 				 "device-manager", manager,
@@ -185,11 +152,9 @@ _clutter_input_device_gdk_new (ClutterDeviceManager    *manager,
 				 "device-type", device_type,
 				 "has-cursor", has_cursor,
 				 "gdk-device", device,
-				 "id", device_id,
+				 "id", device_int_counter++,
 				 "name", name,
 				 "enabled", is_enabled,
-                                 "product-id", product_id,
-                                 "vendor-id", vendor_id,
 				 NULL);
   return clutter_device;
 }
