@@ -22,11 +22,13 @@
  */
 #include "config.h"
 
-#import "clutter-osx.h"
-#import "clutter-backend-osx.h"
-#import "clutter-device-manager-osx.h"
-#import "clutter-stage-osx.h"
-#import "clutter-event-loop-osx.h"
+#include "clutter-osx.h"
+
+#include "clutter-backend-osx.h"
+#include "clutter-device-manager-osx.h"
+#include "clutter-shader.h"
+#include "clutter-stage-osx.h"
+#include "clutter-event-loop-osx.h"
 
 #include "clutter-debug.h"
 #include "clutter-private.h"
@@ -42,9 +44,6 @@
 
 G_DEFINE_TYPE (ClutterBackendOSX, clutter_backend_osx, CLUTTER_TYPE_BACKEND)
 
-/* various flags corresponding to pre init setup calls */
-static gboolean _no_event_retrieval = FALSE;
-
 /*************************************************************************/
 static gboolean
 clutter_backend_osx_post_parse (ClutterBackend  *backend,
@@ -70,25 +69,9 @@ clutter_backend_osx_post_parse (ClutterBackend  *backend,
   /* set the default font name */
   g_object_set (settings, "font-name", DEFAULT_FONT_NAME, NULL);
 
-  /* finish launching the application */
-  [NSApp finishLaunching];
-
   return TRUE;
 }
 
-void
-clutter_osx_disable_event_retrieval (void)
-{
-  if (_clutter_context_is_initialized ())
-    {
-      g_warning ("clutter_osx_disable_event_retrieval() can only be "
-                 "called before clutter_init()");
-      return;
-    }
-
-  _no_event_retrieval = TRUE;
-}
-
 static ClutterFeatureFlags
 clutter_backend_osx_get_features (ClutterBackend *backend)
 {
@@ -111,8 +94,7 @@ _clutter_backend_osx_events_init (ClutterBackend *backend)
                   "backend", CLUTTER_BACKEND(backend_osx),
                   NULL);
 
-  if (!_no_event_retrieval)
-    _clutter_osx_event_loop_init ();
+  _clutter_osx_event_loop_init ();
 }
 
 static gboolean
@@ -154,9 +136,6 @@ clutter_backend_osx_create_context (ClutterBackend  *backend,
 
   [backend_osx->context makeCurrentContext];
 
-  CLUTTER_BACKEND_CLASS (clutter_backend_osx_parent_class)->create_context (backend,
-                                                                            error);
-
   CLUTTER_OSX_POOL_RELEASE();
 
   return TRUE;
