@@ -32,6 +32,14 @@
 
 #import <AppKit/AppKit.h>
 
+enum
+{
+  PROP_0,
+
+  PROP_BACKEND,
+  PROP_WRAPPER
+};
+
 static void clutter_stage_window_iface_init (ClutterStageWindowIface *iface);
 
 #define clutter_stage_osx_get_type      _clutter_stage_osx_get_type
@@ -42,12 +50,6 @@ G_DEFINE_TYPE_WITH_CODE (ClutterStageOSX,
                          G_IMPLEMENT_INTERFACE (CLUTTER_TYPE_STAGE_WINDOW,
                                                 clutter_stage_window_iface_init))
 
-/* FIXME: this should be in clutter-stage.c */
-static void
-clutter_stage_osx_state_update (ClutterStageOSX   *self,
-                                ClutterStageState  unset_flags,
-                                ClutterStageState  set_flags);
-
 static ClutterActor *
 clutter_stage_osx_get_wrapper (ClutterStageWindow *stage_window);
 
@@ -79,7 +81,7 @@ clutter_stage_osx_get_wrapper (ClutterStageWindow *stage_window);
   CLUTTER_NOTE (BACKEND, "[%p] windowShouldClose", self->stage_osx);
 
   event.type = CLUTTER_DELETE;
-  event.any.stage = CLUTTER_STAGE (self->stage_osx->wrapper);
+  event.any.stage = self->stage_osx->wrapper;
   clutter_event_put (&event);
 
   return NO;
@@ -96,30 +98,39 @@ clutter_stage_osx_get_wrapper (ClutterStageWindow *stage_window);
 
 - (void) windowDidBecomeKey:(NSNotification*)aNotification
 {
+  ClutterStage *stage;
+
   CLUTTER_NOTE (BACKEND, "[%p] windowDidBecomeKey", self->stage_osx);
 
-  if (self->stage_osx->stage_state & CLUTTER_STAGE_STATE_FULLSCREEN)
+  stage = self->stage_osx->wrapper;
+
+  if (_clutter_stage_is_fullscreen (stage))
     [self setLevel: CLUTTER_OSX_FULLSCREEN_WINDOW_LEVEL];
 
-  clutter_stage_osx_state_update (self->stage_osx, 0, CLUTTER_STAGE_STATE_ACTIVATED);
+  _clutter_stage_update_state (stage, 0, CLUTTER_STAGE_STATE_ACTIVATED);
 }
 
 - (void) windowDidResignKey:(NSNotification*)aNotification
 {
+  ClutterStage *stage;
+
   CLUTTER_NOTE (BACKEND, "[%p] windowDidResignKey", self->stage_osx);
 
-  if (self->stage_osx->stage_state & CLUTTER_STAGE_STATE_FULLSCREEN)
+  stage = self->stage_osx->wrapper;
+
+  if (_clutter_stage_is_fullscreen (stage))
     {
       [self setLevel: NSNormalWindowLevel];
-      [self orderBack: nil];
+      if (!self->stage_osx->isHiding)
+        [self orderBack: nil];
     }
 
-  clutter_stage_osx_state_update (self->stage_osx, CLUTTER_STAGE_STATE_ACTIVATED, 0);
+  _clutter_stage_update_state (stage, CLUTTER_STAGE_STATE_ACTIVATED, 0);
 }
 
 - (NSSize) windowWillResize:(NSWindow *) sender toSize:(NSSize) frameSize
 {
-  if ( clutter_stage_get_user_resizable (self->stage_osx->wrapper) )
+  if (clutter_stage_get_user_resizable (self->stage_osx->wrapper))
     {
       guint min_width, min_height;
       clutter_stage_get_minimum_size (self->stage_osx->wrapper,
@@ -131,6 +142,11 @@ clutter_stage_osx_get_wrapper (ClutterStageWindow *stage_window);
   else 
     return [self frame].size;
 }
+
+- (void)windowDidChangeScreen:(NSNotification *)notification
+{
+  clutter_stage_ensure_redraw (self->stage_osx->wrapper);
+}
 @end
 
 /*************************************************************************/
@@ -148,7 +164,10 @@ clutter_stage_osx_get_wrapper (ClutterStageWindow *stage_window);
   if ((self = [super initWithFrame:aFrame pixelFormat:aFormat]) != nil)
     {
       self->stage_osx = aStage;
-      tracking_rect = [self addTrackingRect:[self bounds] owner:self userData:NULL assumeInside:NO];
+      tracking_rect = [self addTrackingRect:[self bounds]
+                                      owner:self
+                                   userData:NULL
+                               assumeInside:NO];
     }
 
   return self;
@@ -159,7 +178,6 @@ clutter_stage_osx_get_wrapper (ClutterStageWindow *stage_window);
   _clutter_stage_do_paint (CLUTTER_STAGE (self->stage_osx->wrapper), NULL);
   cogl_flush ();
   [[self openGLContext] flushBuffer];
-  _cogl_swap_buffers_notify ();
 }
 
 /* In order to receive key events */
@@ -174,22 +192,36 @@ clutter_stage_osx_get_wrapper (ClutterStageWindow *stage_window);
   return YES;
 }
 
+- (BOOL) isOpaque
+{
+  if (clutter_stage_get_use_alpha (CLUTTER_STAGE (self->stage_osx->wrapper)))
+    return NO;
+
+  return YES;
+}
+
 - (void) reshape
 {
   stage_osx->requisition_width = [self bounds].size.width;
   stage_osx->requisition_height = [self bounds].size.height;
   clutter_actor_set_size (CLUTTER_ACTOR (self->stage_osx->wrapper),
-                          (int)[self bounds].size.width, (int)[self bounds].size.height);
+                          stage_osx->requisition_width,
+                          stage_osx->requisition_height);
 
   [self removeTrackingRect:tracking_rect];
-  tracking_rect = [self addTrackingRect:[self bounds] owner:self userData:NULL assumeInside:NO];
+  tracking_rect = [self addTrackingRect:[self bounds]
+                                  owner:self
+                               userData:NULL
+                           assumeInside:NO];
 }
 
 /* Simply forward all events that reach our view to clutter. */
 
-#define EVENT_HANDLER(event) -(void)event:(NSEvent *)theEvent { \
+#define EVENT_HANDLER(event) \
+-(void)event:(NSEvent *) theEvent { \
   _clutter_event_osx_put (theEvent, self->stage_osx->wrapper);  \
 }
+
 EVENT_HANDLER(mouseDown)
 EVENT_HANDLER(mouseDragged)
 EVENT_HANDLER(mouseUp)
@@ -214,28 +246,6 @@ EVENT_HANDLER(tabletProximity)
 @end
 
 /*************************************************************************/
-static void
-clutter_stage_osx_state_update (ClutterStageOSX   *self,
-                                ClutterStageState  unset_flags,
-                                ClutterStageState  set_flags)
-{
-  ClutterStageStateEvent event;
-
-  event.new_state = self->stage_state;
-  event.new_state |= set_flags;
-  event.new_state &= ~unset_flags;
-
-  if (event.new_state == self->stage_state)
-    return;
-
-  event.changed_mask = event.new_state ^ self->stage_state;
-
-  self->stage_state = event.new_state;
-
-  event.type = CLUTTER_STAGE_STATE;
-  event.stage = CLUTTER_STAGE (self->wrapper);
-  clutter_event_put ((ClutterEvent*)&event);
-}
 
 static void
 clutter_stage_osx_save_frame (ClutterStageOSX *self)
@@ -251,7 +261,7 @@ clutter_stage_osx_set_frame (ClutterStageOSX *self)
 {
   g_assert (self->window != NULL);
 
-  if (self->stage_state & CLUTTER_STAGE_STATE_FULLSCREEN)
+  if (_clutter_stage_is_fullscreen (self->wrapper))
     {
       /* Raise above the menubar (and dock) covering the whole screen.
        *
@@ -262,7 +272,8 @@ clutter_stage_osx_set_frame (ClutterStageOSX *self)
        */
       [self->window setLevel: CLUTTER_OSX_FULLSCREEN_WINDOW_LEVEL];
 
-      [self->window setFrame: [self->window frameRectForContentRect: [[self->window screen] frame]] display: NO];
+      [self->window setFrame: [self->window frameRectForContentRect: [[self->window screen] frame]]
+                                                            display: NO];
     }
   else
     {
@@ -271,8 +282,10 @@ clutter_stage_osx_set_frame (ClutterStageOSX *self)
       if (self->haveNormalFrame)
         [self->window setFrame: self->normalFrame display: NO];
       else
-        /* looks better than positioning to 0,0 (bottom right) */
-        [self->window center];
+        {
+          /* looks better than positioning to 0,0 (bottom right) */
+          [self->window center];
+        }
     }
 }
 
@@ -281,7 +294,6 @@ static gboolean
 clutter_stage_osx_realize (ClutterStageWindow *stage_window)
 {
   ClutterStageOSX *self = CLUTTER_STAGE_OSX (stage_window);
-  ClutterBackendOSX *backend_osx;
   gfloat width, height;
   NSRect rect;
 
@@ -289,32 +301,39 @@ clutter_stage_osx_realize (ClutterStageWindow *stage_window)
 
   CLUTTER_NOTE (BACKEND, "[%p] realize", self);
 
-  backend_osx = CLUTTER_BACKEND_OSX (self->backend);
-  /* Call get_size - this will either get the geometry size (which
-   * before we create the window is set to 640x480), or if a size
-   * is set, it will get that. This lets you set a size on the
-   * stage before it's realized.
-   */
-  clutter_actor_get_size (CLUTTER_ACTOR (self->wrapper), &width, &height);
-  self->requisition_width = width; 
-  self->requisition_height= height;
+  if (!self->haveRealized)
+    {
+      ClutterBackendOSX *backend_osx;
 
-  rect = NSMakeRect(0, 0, self->requisition_width, self->requisition_height);
+      backend_osx = CLUTTER_BACKEND_OSX (self->backend);
 
-  self->view = [[ClutterGLView alloc]
-                initWithFrame: rect
-                  pixelFormat: backend_osx->pixel_format
-                        stage: self];
-  [self->view setOpenGLContext:backend_osx->context];
+      /* Call get_size - this will either get the geometry size (which
+       * before we create the window is set to 640x480), or if a size
+       * is set, it will get that. This lets you set a size on the
+       * stage before it's realized.
+       */
+      clutter_actor_get_size (CLUTTER_ACTOR (self->wrapper), &width, &height);
+      self->requisition_width = width;
+      self->requisition_height= height;
 
-  self->window = [[ClutterGLWindow alloc]
-                  initWithView: self->view
-                     UTF8Title: clutter_stage_get_title (CLUTTER_STAGE (self->wrapper))
-                         stage: self];
-  /* looks better than positioning to 0,0 (bottom right) */
-  [self->window center];
+      rect = NSMakeRect (0, 0, self->requisition_width, self->requisition_height);
 
-  CLUTTER_NOTE (BACKEND, "Stage successfully realized");
+      self->view = [[ClutterGLView alloc]
+                    initWithFrame: rect
+                      pixelFormat: backend_osx->pixel_format
+                            stage: self];
+      [self->view setOpenGLContext:backend_osx->context];
+
+      self->window = [[ClutterGLWindow alloc]
+                      initWithView: self->view
+                         UTF8Title: clutter_stage_get_title (CLUTTER_STAGE (self->wrapper))
+                             stage: self];
+      /* looks better than positioning to 0,0 (bottom right) */
+      [self->window center];
+      self->haveRealized = true;
+
+      CLUTTER_NOTE (BACKEND, "Stage successfully realized");
+    }
 
   CLUTTER_OSX_POOL_RELEASE();
 
@@ -338,6 +357,7 @@ clutter_stage_osx_unrealize (ClutterStageWindow *stage_window)
 
   self->view = NULL;
   self->window = NULL;
+  self->haveRealized = false;
 
   CLUTTER_OSX_POOL_RELEASE();
 }
@@ -371,6 +391,7 @@ clutter_stage_osx_show (ClutterStageWindow *stage_window,
     [self->window orderFront: nil];
 
   [self->view setHidden:isViewHidden];
+  [self->window setExcludedFromWindowsMenu:NO];
 
   /*
    * After hiding we cease to be first responder.
@@ -389,16 +410,20 @@ clutter_stage_osx_hide (ClutterStageWindow *stage_window)
 
   CLUTTER_NOTE (BACKEND, "[%p] hide", self);
 
+  self->isHiding = true;
   [self->window orderOut: nil];
+  [self->window setExcludedFromWindowsMenu:YES];
 
   clutter_actor_unmap (CLUTTER_ACTOR (self->wrapper));
 
+  self->isHiding = false;
+
   CLUTTER_OSX_POOL_RELEASE();
 }
 
 static void
-clutter_stage_osx_get_geometry (ClutterStageWindow *stage_window,
-                                ClutterGeometry    *geometry)
+clutter_stage_osx_get_geometry (ClutterStageWindow    *stage_window,
+                                cairo_rectangle_int_t *geometry)
 {
   ClutterBackend *backend = clutter_get_default_backend ();
   ClutterStageOSX *self = CLUTTER_STAGE_OSX (stage_window);
@@ -424,7 +449,8 @@ clutter_stage_osx_resize (ClutterStageWindow *stage_window,
   clutter_stage_get_minimum_size (CLUTTER_STAGE (actor),
                                   &min_width,
                                   &min_height);
-  [self->window setContentMinSize:NSMakeSize(min_width, min_height)];
+
+  [self->window setContentMinSize: NSMakeSize (min_width, min_height)];
   
   width = width < min_width ? min_width : width;
   height = height < min_height ? min_height : height;
@@ -482,11 +508,17 @@ clutter_stage_osx_set_fullscreen (ClutterStageWindow *stage_window,
    */
   if (fullscreen)
     {
-      clutter_stage_osx_state_update (self, 0, CLUTTER_STAGE_STATE_FULLSCREEN);
+      _clutter_stage_update_state (CLUTTER_STAGE (self->wrapper),
+                                   0,
+                                   CLUTTER_STAGE_STATE_FULLSCREEN);
       clutter_stage_osx_save_frame (self);
     }
   else
-    clutter_stage_osx_state_update (self, CLUTTER_STAGE_STATE_FULLSCREEN, 0);
+    {
+      _clutter_stage_update_state (CLUTTER_STAGE (self->wrapper),
+                                   CLUTTER_STAGE_STATE_FULLSCREEN,
+                                   0);
+    }
 
   clutter_stage_osx_set_frame (self);
 
@@ -563,20 +595,6 @@ clutter_stage_window_iface_init (ClutterStageWindowIface *iface)
   iface->redraw             = clutter_stage_osx_redraw;
 }
 
-/*************************************************************************/
-ClutterStageWindow *
-_clutter_stage_osx_new (ClutterBackend *backend,
-                        ClutterStage   *wrapper)
-{
-  ClutterStageOSX *self;
-
-  self = g_object_new (CLUTTER_TYPE_STAGE_OSX, NULL);
-  self->backend = backend;
-  self->wrapper = wrapper;
-
-  return CLUTTER_STAGE_WINDOW(self);
-}
-
 /*************************************************************************/
 static void
 clutter_stage_osx_init (ClutterStageOSX *self)
@@ -584,6 +602,35 @@ clutter_stage_osx_init (ClutterStageOSX *self)
   self->requisition_width  = 640;
   self->requisition_height = 480;
   self->acceptFocus = TRUE;
+
+  self->isHiding = false;
+  self->haveRealized = false;
+  self->view = NULL;
+  self->window = NULL;
+}
+
+static void
+clutter_stage_osx_set_property (GObject      *gobject,
+                                guint         prop_id,
+                                const GValue *value,
+                                GParamSpec   *pspec)
+{
+  ClutterStageOSX *self = CLUTTER_STAGE_OSX (gobject);
+
+  switch (prop_id)
+    {
+    case PROP_BACKEND:
+      self->backend = g_value_get_object (value);
+      break;
+
+    case PROP_WRAPPER:
+      self->wrapper = g_value_get_object (value);
+      break;
+
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, prop_id, pspec);
+      break;
+    }
 }
 
 static void
@@ -603,6 +650,10 @@ clutter_stage_osx_class_init (ClutterStageOSXClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
+  gobject_class->set_property = clutter_stage_osx_set_property;
   gobject_class->finalize = clutter_stage_osx_finalize;
   gobject_class->dispose = clutter_stage_osx_dispose;
+
+  g_object_class_override_property (gobject_class, PROP_BACKEND, "backend");
+  g_object_class_override_property (gobject_class, PROP_WRAPPER, "wrapper");
 }
