@@ -32,16 +32,14 @@
 #include <stdlib.h>
 #include <wayland-client.h>
 
-#include "clutter-event.h"
-#include "clutter-main.h"
-#include "clutter-private.h"
-#include "clutter-stage-private.h"
-
-#include "clutter-event-wayland.h"
+#include "../clutter-event.h"
+#include "../clutter-main.h"
 
 typedef struct _ClutterEventSourceWayland
 {
   GSource source;
+  GPollFD pfd;
+  uint32_t mask;
   struct wl_display *display;
 } ClutterEventSourceWayland;
 
@@ -51,7 +49,7 @@ clutter_event_source_wayland_prepare (GSource *base, gint *timeout)
   ClutterEventSourceWayland *source = (ClutterEventSourceWayland *) base;
   gboolean retval;
 
-  _clutter_threads_acquire_lock ();
+  clutter_threads_enter ();
 
   *timeout = -1;
 
@@ -62,7 +60,7 @@ clutter_event_source_wayland_prepare (GSource *base, gint *timeout)
 
   retval = clutter_events_pending ();
 
-  _clutter_threads_release_lock ();
+  clutter_threads_leave ();
 
   return retval;
 }
@@ -70,13 +68,14 @@ clutter_event_source_wayland_prepare (GSource *base, gint *timeout)
 static gboolean
 clutter_event_source_wayland_check (GSource *base)
 {
+  ClutterEventSourceWayland *source = (ClutterEventSourceWayland *) base;
   gboolean retval;
 
-  _clutter_threads_acquire_lock ();
+  clutter_threads_enter ();
 
-  retval = clutter_events_pending ();
+  retval = clutter_events_pending () || source->pfd.revents;
 
-  _clutter_threads_release_lock ();
+  clutter_threads_leave ();
 
   return retval;
 }
@@ -86,19 +85,27 @@ clutter_event_source_wayland_dispatch (GSource *base,
 				       GSourceFunc callback,
 				       gpointer data)
 {
+  ClutterEventSourceWayland *source = (ClutterEventSourceWayland *) base;
   ClutterEvent *event;
 
-  _clutter_threads_acquire_lock ();
+  clutter_threads_enter ();
+
+  if (source->pfd.revents)
+    {
+      wl_display_iterate (source->display, WL_DISPLAY_READABLE);
+      source->pfd.revents = 0;
+    }
 
   event = clutter_event_get ();
 
   if (event)
     {
       /* forward the event into clutter for emission etc. */
-      _clutter_stage_queue_event (event->any.stage, event, FALSE);
+      clutter_do_event (event);
+      clutter_event_free (event);
     }
 
-  _clutter_threads_release_lock ();
+  clutter_threads_leave ();
 
   return TRUE;
 }
@@ -110,6 +117,15 @@ static GSourceFuncs clutter_event_source_wayland_funcs = {
     NULL
 };
 
+static int
+clutter_event_source_wayland_update (uint32_t mask, void *data)
+{
+  ClutterEventSourceWayland *source = data;
+
+  source->mask = mask;
+
+  return 0;
+}
 
 GSource *
 _clutter_event_source_wayland_new (struct wl_display *display)
@@ -120,6 +136,11 @@ _clutter_event_source_wayland_new (struct wl_display *display)
     g_source_new (&clutter_event_source_wayland_funcs,
                   sizeof (ClutterEventSourceWayland));
   source->display = display;
+  source->pfd.fd =
+    wl_display_get_fd (display,
+                       clutter_event_source_wayland_update, source);
+  source->pfd.events = G_IO_IN | G_IO_ERR;
+  g_source_add_poll (&source->source, &source->pfd);
 
   return &source->source;
 }
