@@ -54,18 +54,22 @@
 enum
 {
   PROP_SURFACE = 1,
-  PROP_WIDTH,
-  PROP_HEIGHT
+  PROP_SURFACE_WIDTH,
+  PROP_SURFACE_HEIGHT,
+  PROP_COGL_TEXTURE,
+  PROP_LAST
 };
 
-#if 0
+static GParamSpec *obj_props[PROP_LAST];
+
 enum
 {
+  QUEUE_DAMAGE_REDRAW,
+
   LAST_SIGNAL
 };
 
 static guint signals[LAST_SIGNAL] = { 0, };
-#endif
 
 struct _ClutterWaylandSurfacePrivate
 {
@@ -73,7 +77,6 @@ struct _ClutterWaylandSurfacePrivate
   CoglTexture2D *buffer;
   int width, height;
   CoglPipeline *pipeline;
-  GArray *damage;
 };
 
 G_DEFINE_TYPE (ClutterWaylandSurface,
@@ -99,7 +102,6 @@ clutter_wayland_surface_queue_damage_redraw (ClutterWaylandSurface *texture,
   ClutterActorBox allocation;
   float scale_x;
   float scale_y;
-  ClutterVertex origin;
   cairo_rectangle_int_t clip;
 
   /* NB: clutter_actor_queue_redraw_with_clip expects a box in the actor's
@@ -163,24 +165,34 @@ clutter_wayland_surface_init (ClutterWaylandSurface *self)
   priv->surface = NULL;
   priv->width = 0;
   priv->height = 0;
-  priv->damage = g_array_new (FALSE, FALSE, sizeof (int));
 
   self->priv = priv;
 
   g_signal_connect (self, "notify::opacity", G_CALLBACK (opacity_change_cb), NULL);
 }
 
+static void
+free_surface_buffers (ClutterWaylandSurface *self)
+{
+  ClutterWaylandSurfacePrivate *priv = self->priv;
+
+  if (priv->buffer)
+    {
+      cogl_object_unref (priv->buffer);
+      priv->buffer = NULL;
+      free_pipeline (self);
+    }
+}
+
 static void
 clutter_wayland_surface_dispose (GObject *object)
 {
   ClutterWaylandSurface *self = CLUTTER_WAYLAND_SURFACE (object);
   ClutterWaylandSurfacePrivate *priv = self->priv;
 
-  if (priv->damage)
-    {
-      g_array_free (priv->damage, TRUE);
-      priv->damage = NULL;
-    }
+  free_pipeline (self);
+  free_surface_buffers (self);
+  priv->surface = NULL;
 
   G_OBJECT_CLASS (clutter_wayland_surface_parent_class)->dispose (object);
 }
@@ -195,16 +207,25 @@ set_size (ClutterWaylandSurface *self,
   if (priv->width != width)
     {
       priv->width = width;
-      g_object_notify (G_OBJECT (self), "width");
+      g_object_notify_by_pspec (G_OBJECT (self), obj_props[PROP_SURFACE_WIDTH]);
     }
   if (priv->height != height)
     {
       priv->height = height;
-      g_object_notify (G_OBJECT (self), "height");
+      g_object_notify_by_pspec (G_OBJECT (self), obj_props[PROP_SURFACE_HEIGHT]);
     }
+
+  clutter_actor_set_size (CLUTTER_ACTOR (self), priv->width, priv->height);
 }
 
-static void
+struct wl_surface *
+clutter_wayland_surface_get_surface (ClutterWaylandSurface *self)
+{
+  ClutterWaylandSurfacePrivate *priv = self->priv;
+  return priv->surface;
+}
+
+void
 clutter_wayland_surface_set_surface (ClutterWaylandSurface *self,
                                      struct wl_surface *surface)
 {
@@ -214,12 +235,23 @@ clutter_wayland_surface_set_surface (ClutterWaylandSurface *self,
 
   priv = self->priv;
 
-  g_return_if_fail (priv->surface == NULL);
+  if (priv->surface == surface)
+    return;
+
+  if (priv->surface)
+    {
+      free_pipeline (self);
+      free_surface_buffers (self);
+      g_signal_emit (self, signals[QUEUE_DAMAGE_REDRAW],
+                     0,
+                     0, 0, priv->width, priv->height);
+    }
+
   priv->surface = surface;
 
   /* XXX: should we freeze/thaw notifications? */
 
-  g_object_notify (G_OBJECT (self), "surface");
+  g_object_notify_by_pspec (G_OBJECT (self), obj_props[PROP_SURFACE]);
 
   /* We have to wait until the next attach event to find out the surface
    * geometry... */
@@ -259,10 +291,10 @@ clutter_wayland_surface_get_property (GObject *object,
     case PROP_SURFACE:
       g_value_set_pointer (value, priv->surface);
       break;
-    case PROP_WIDTH:
+    case PROP_SURFACE_WIDTH:
       g_value_set_uint (value, priv->width);
       break;
-    case PROP_HEIGHT:
+    case PROP_SURFACE_HEIGHT:
       g_value_set_uint (value, priv->height);
       break;
     default:
@@ -302,18 +334,6 @@ clutter_wayland_surface_paint (ClutterActor *self)
   cogl_rectangle (0, 0, box.x2 - box.x1, box.y2 - box.y1);
 }
 
-static void
-clutter_wayland_surface_pick (ClutterActor *self,
-                              const ClutterColor *color)
-{
-  ClutterActorBox box;
-
-  cogl_set_source_color4ub (color->red, color->green, color->blue,
-                            color->alpha);
-  clutter_actor_get_allocation_box (self, &box);
-  cogl_rectangle (0, 0, box.x2 - box.x1, box.y2 - box.y1);
-}
-
 static void
 clutter_wayland_surface_get_preferred_width (ClutterActor *self,
                                              gfloat for_height,
@@ -371,7 +391,6 @@ clutter_wayland_surface_class_init (ClutterWaylandSurfaceClass *klass)
 
   actor_class->get_paint_volume = clutter_wayland_surface_get_paint_volume;
   actor_class->paint = clutter_wayland_surface_paint;
-  actor_class->pick = clutter_wayland_surface_pick;
   actor_class->get_preferred_width =
     clutter_wayland_surface_get_preferred_width;
   actor_class->get_preferred_height =
@@ -387,26 +406,69 @@ clutter_wayland_surface_class_init (ClutterWaylandSurfaceClass *klass)
 			        P_("The underlying wayland surface"),
                                 CLUTTER_PARAM_READWRITE|
                                 G_PARAM_CONSTRUCT_ONLY);
-
+  obj_props[PROP_SURFACE] = pspec;
   g_object_class_install_property (object_class, PROP_SURFACE, pspec);
 
-  pspec = g_param_spec_uint ("width",
+  pspec = g_param_spec_uint ("surface-width",
                              P_("Surface width"),
                              P_("The width of the underlying wayland surface"),
                              0, G_MAXUINT,
                              0,
                              G_PARAM_READABLE);
+  obj_props[PROP_SURFACE_WIDTH] = pspec;
+  g_object_class_install_property (object_class, PROP_SURFACE_WIDTH, pspec);
 
-  g_object_class_install_property (object_class, PROP_WIDTH, pspec);
-
-  pspec = g_param_spec_uint ("height",
+  pspec = g_param_spec_uint ("surface-height",
                              P_("Surface height"),
                              P_("The height of the underlying wayland surface"),
                              0, G_MAXUINT,
                              0,
                              G_PARAM_READABLE);
+  obj_props[PROP_SURFACE_HEIGHT] = pspec;
+  g_object_class_install_property (object_class, PROP_SURFACE_HEIGHT, pspec);
 
-  g_object_class_install_property (object_class, PROP_HEIGHT, pspec);
+  pspec = g_param_spec_boxed ("cogl-texture",
+                              P_("Cogl Texture"),
+                              P_("The underlying Cogl texture handle used to draw this actor"),
+                              COGL_TYPE_HANDLE,
+                              CLUTTER_PARAM_READWRITE);
+  obj_props[PROP_COGL_TEXTURE] = pspec;
+  g_object_class_install_property (object_class, PROP_COGL_TEXTURE, pspec);
+
+  /**
+   * ClutterWaylandSurface::queue-damage-redraw
+   * @texture: the object which received the signal
+   * @x: The top left x position of the damage region
+   * @y: The top left y position of the damage region
+   * @width: The width of the damage region
+   * @height: The height of the damage region
+   *
+   * ::queue-damage-redraw is emitted to notify that some sub-region
+   * of the texture has been changed. This usually means a redraw
+   * needs to be queued for the actor.
+   *
+   * The default handler will queue a clipped redraw in response to
+   * the damage, using the assumption that the pixmap is being painted
+   * to a rectangle covering the transformed allocation of the actor.
+   * If you sub-class and change the paint method so this isn't true
+   * then you must also provide your own damage signal handler to
+   * queue a redraw that blocks this default behaviour.
+   *
+   * Since: 1.10
+   */
+  signals[QUEUE_DAMAGE_REDRAW] =
+    g_signal_new (g_intern_static_string ("queue-damage-redraw"),
+                  G_TYPE_FROM_CLASS (object_class),
+                  G_SIGNAL_RUN_FIRST,
+                  G_STRUCT_OFFSET (ClutterWaylandSurfaceClass, queue_damage_redraw),
+                  NULL, NULL,
+                  _clutter_marshal_VOID__INT_INT_INT_INT,
+                  G_TYPE_NONE, 4,
+                  G_TYPE_INT,
+                  G_TYPE_INT,
+                  G_TYPE_INT,
+                  G_TYPE_INT);
+  klass->queue_damage_redraw = clutter_wayland_surface_queue_damage_redraw;
 }
 
 /**
@@ -432,19 +494,6 @@ clutter_wayland_surface_new (struct wl_surface *surface)
   return actor;
 }
 
-static void
-free_surface_buffers (ClutterWaylandSurface *self)
-{
-  ClutterWaylandSurfacePrivate *priv = self->priv;
-
-  if (priv->buffer)
-    {
-      cogl_object_unref (priv->buffer);
-      priv->buffer = NULL;
-      free_pipeline (self);
-    }
-}
-
 /**
  * clutter_wayland_surface_attach_buffer:
  * @self: A #ClutterWaylandSurface actor
@@ -478,7 +527,12 @@ clutter_wayland_surface_attach_buffer (ClutterWaylandSurface *self,
   priv->buffer =
     cogl_wayland_texture_2d_new_from_buffer (context, buffer, error);
 
-  clutter_actor_queue_redraw (CLUTTER_ACTOR (self));
+  g_object_notify_by_pspec (G_OBJECT (self), obj_props[PROP_COGL_TEXTURE]);
+
+  /* NB: We don't queue a redraw of the actor here because we don't
+   * know how much of the buffer has changed with respect to the
+   * previous buffer. We only ever queue a redraw in response to
+   * surface damage. */
 
   if (!priv->buffer)
     return FALSE;
@@ -526,19 +580,17 @@ clutter_wayland_surface_damage_buffer (ClutterWaylandSurface *self,
       switch (wl_shm_buffer_get_format (buffer))
         {
 #if G_BYTE_ORDER == G_BIG_ENDIAN
-          case WL_SHM_FORMAT_PREMULTIPLIED_ARGB32:
+          case WL_SHM_FORMAT_ARGB8888:
             format = COGL_PIXEL_FORMAT_ARGB_8888_PRE;
             break;
-          case WL_SHM_FORMAT_ARGB32:
-          case WL_SHM_FORMAT_XRGB32:
+          case WL_SHM_FORMAT_XRGB8888:
             format = COGL_PIXEL_FORMAT_ARGB_8888;
             break;
 #elif G_BYTE_ORDER == G_LITTLE_ENDIAN
-          case WL_SHM_FORMAT_PREMULTIPLIED_ARGB32:
+          case WL_SHM_FORMAT_ARGB8888:
             format = COGL_PIXEL_FORMAT_BGRA_8888_PRE;
             break;
-          case WL_SHM_FORMAT_ARGB32:
-          case WL_SHM_FORMAT_XRGB32:
+          case WL_SHM_FORMAT_XRGB8888:
             format = COGL_PIXEL_FORMAT_BGRA_8888;
             break;
 #endif
@@ -557,5 +609,15 @@ clutter_wayland_surface_damage_buffer (ClutterWaylandSurface *self,
                                wl_shm_buffer_get_data (buffer));
     }
 
-  clutter_wayland_surface_queue_damage_redraw (self, x, y, width, height);
+  g_signal_emit (self, signals[QUEUE_DAMAGE_REDRAW],
+                 0,
+                 x, y, width, height);
+}
+
+CoglTexture *
+clutter_wayland_surface_get_cogl_texture (ClutterWaylandSurface *self)
+{
+  g_return_val_if_fail (CLUTTER_WAYLAND_IS_SURFACE (self), NULL);
+
+  return COGL_TEXTURE (self->priv->buffer);
 }
