@@ -27,7 +27,6 @@
 
 #include "clutter-debug.h"
 #include "clutter-device-manager-private.h"
-#include "clutter-event-private.h"
 #include "clutter-private.h"
 #include "clutter-stage-private.h"
 
@@ -54,6 +53,57 @@ G_DEFINE_TYPE (ClutterInputDeviceXI2,
                clutter_input_device_xi2,
                CLUTTER_TYPE_INPUT_DEVICE);
 
+static void
+clutter_input_device_xi2_select_stage_events (ClutterInputDevice *device,
+                                              ClutterStage       *stage,
+                                              gint                event_mask)
+{
+  ClutterInputDeviceXI2 *device_xi2 = CLUTTER_INPUT_DEVICE_XI2 (device);
+  ClutterBackendX11 *backend_x11;
+  ClutterStageX11 *stage_x11;
+  XIEventMask xi_event_mask;
+  unsigned char *mask;
+  int len;
+
+  backend_x11 = CLUTTER_BACKEND_X11 (device->backend);
+  stage_x11 = CLUTTER_STAGE_X11 (_clutter_stage_get_window (stage));
+
+  len = XIMaskLen (XI_LASTEVENT);
+  mask = g_new0 (unsigned char, len);
+
+  if (event_mask & PointerMotionMask)
+    XISetMask (mask, XI_Motion);
+
+  if (event_mask & ButtonPressMask)
+    XISetMask (mask, XI_ButtonPress);
+
+  if (event_mask & ButtonReleaseMask)
+    XISetMask (mask, XI_ButtonRelease);
+
+  if (event_mask & KeyPressMask)
+    XISetMask (mask, XI_KeyPress);
+
+  if (event_mask & KeyReleaseMask)
+    XISetMask (mask, XI_KeyRelease);
+
+  if (event_mask & EnterWindowMask)
+    XISetMask (mask, XI_Enter);
+
+  if (event_mask & LeaveWindowMask)
+    XISetMask (mask, XI_Leave);
+
+  xi_event_mask.deviceid = device_xi2->device_id;
+  xi_event_mask.mask = mask;
+  xi_event_mask.mask_len = len;
+
+  CLUTTER_NOTE (BACKEND, "Selecting device id '%d' events",
+                device_xi2->device_id);
+
+  XISelectEvents (backend_x11->xdpy, stage_x11->xwin, &xi_event_mask, 1);
+
+  g_free (mask);
+}
+
 static void
 clutter_input_device_xi2_constructed (GObject *gobject)
 {
@@ -87,6 +137,7 @@ clutter_input_device_xi2_class_init (ClutterInputDeviceXI2Class *klass)
 
   gobject_class->constructed = clutter_input_device_xi2_constructed;
 
+  device_class->select_stage_events = clutter_input_device_xi2_select_stage_events;
   device_class->keycode_to_evdev = clutter_input_device_xi2_keycode_to_evdev;
 }
 
@@ -95,24 +146,14 @@ clutter_input_device_xi2_init (ClutterInputDeviceXI2 *self)
 {
 }
 
-void
-_clutter_input_device_xi2_translate_state (ClutterEvent    *event,
-					   XIModifierState *modifiers_state,
-                                           XIButtonState   *buttons_state,
-                                           XIGroupState    *group_state)
+guint
+_clutter_input_device_xi2_translate_state (XIModifierState *modifiers_state,
+                                           XIButtonState   *buttons_state)
 {
-  guint button = 0;
-  guint base = 0;
-  guint latched = 0;
-  guint locked = 0;
-  guint effective;
+  guint retval = 0;
 
   if (modifiers_state)
-    {
-      base = (guint) modifiers_state->base;
-      latched = (guint) modifiers_state->latched;
-      locked = (guint) modifiers_state->locked;
-    }
+    retval = (guint) modifiers_state->effective;
 
   if (buttons_state)
     {
@@ -128,23 +169,23 @@ _clutter_input_device_xi2_translate_state (ClutterEvent    *event,
           switch (i)
             {
             case 1:
-              button |= CLUTTER_BUTTON1_MASK;
+              retval |= CLUTTER_BUTTON1_MASK;
               break;
 
             case 2:
-              button |= CLUTTER_BUTTON2_MASK;
+              retval |= CLUTTER_BUTTON2_MASK;
               break;
 
             case 3:
-              button |= CLUTTER_BUTTON3_MASK;
+              retval |= CLUTTER_BUTTON3_MASK;
               break;
 
             case 4:
-              button |= CLUTTER_BUTTON4_MASK;
+              retval |= CLUTTER_BUTTON4_MASK;
               break;
 
             case 5:
-              button |= CLUTTER_BUTTON5_MASK;
+              retval |= CLUTTER_BUTTON5_MASK;
               break;
 
             default:
@@ -153,9 +194,5 @@ _clutter_input_device_xi2_translate_state (ClutterEvent    *event,
         }
     }
 
-  effective = button | base | latched | locked;
-  if (group_state)
-    effective |= (group_state->effective) << 13;
-
-  _clutter_event_set_state_full (event, button, base, latched, locked, effective);
+  return retval;
 }
